@@ -28,9 +28,7 @@
 
 #include <QStackedWidget>
 
-#include <KAction>
-#include <KDialog>
-#include <KTabWidget>
+#include <QAction>
 #include <KAboutData>
 #include <KStandardAction>
 #include <KFileItemDelegate>
@@ -169,7 +167,7 @@ void IconMode::initWidget()
     d->categoryDrawer = new CategoryDrawer(d->categoryView);
 
     d->categoryView->setSelectionMode( QAbstractItemView::SingleSelection );
-    d->categoryView->setSpacing( KDialog::spacingHint() );
+    //PORT QT5 d->categoryView->setSpacing( KDialog::spacingHint() );
     d->categoryView->setCategoryDrawer( d->categoryDrawer );
     d->categoryView->setViewMode( QListView::IconMode );
     d->categoryView->setMouseTracking( true );
